==> zio-aws-cloudfront_2.12-7.30.22.2-sources.jar: zio/aws/cloudfront/model/InvalidationList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InvalidationList(
    marker: String,
    nextMarker: Optional[String] = Optional.Absent,
    maxItems: Integer,
    isTruncated: Boolean,
    quantity: Integer,
    items: Optional[Iterable[zio.aws.cloudfront.model.InvalidationSummary]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.InvalidationList = {
    import InvalidationList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.InvalidationList
      .builder()
      .marker(marker: java.lang.String)
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(maxItems: java.lang.Integer)
      .isTruncated(isTruncated: java.lang.Boolean)
      .quantity(quantity: java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.InvalidationList.ReadOnly =
    zio.aws.cloudfront.model.InvalidationList.wrap(buildAwsValue())
}
object InvalidationList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.InvalidationList =
      zio.aws.cloudfront.model.InvalidationList(
        marker,
        nextMarker.map(value => value),
        maxItems,
        isTruncated,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: String
    def nextMarker: Optional[String]
    def maxItems: Integer
    def isTruncated: Boolean
    def quantity: Integer
    def items
        : Optional[List[zio.aws.cloudfront.model.InvalidationSummary.ReadOnly]]
    def getMarker: ZIO[Any, Nothing, String] = ZIO.succeed(marker)
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getIsTruncated: ZIO[Any, Nothing, Boolean] = ZIO.succeed(isTruncated)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.InvalidationSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ) extends zio.aws.cloudfront.model.InvalidationList.ReadOnly {
    override val marker: String = impl.marker(): String
    override val nextMarker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => value: String)
    override val maxItems: Integer = impl.maxItems(): Integer
    override val isTruncated: Boolean = impl.isTruncated(): Boolean
    override val quantity: Integer = impl.quantity(): Integer
    override val items: Optional[
      List[zio.aws.cloudfront.model.InvalidationSummary.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.items())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.cloudfront.model.InvalidationSummary.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ): zio.aws.cloudfront.model.InvalidationList.ReadOnly = new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-5.17.104.1-sources.jar: zio/aws/cloudfront/model/InvalidationList.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.cloudfront.model.primitives.Integer
import scala.jdk.CollectionConverters._
final case class InvalidationList(
    marker: String,
    nextMarker: Option[String] = None,
    maxItems: Integer,
    isTruncated: Boolean,
    quantity: Integer,
    items: Option[Iterable[zio.aws.cloudfront.model.InvalidationSummary]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.InvalidationList = {
    import InvalidationList.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.InvalidationList
      .builder()
      .marker(marker: java.lang.String)
      .optionallyWith(nextMarker.map(value => value: java.lang.String))(
        _.nextMarker
      )
      .maxItems(Integer.unwrap(maxItems): java.lang.Integer)
      .isTruncated(isTruncated: java.lang.Boolean)
      .quantity(Integer.unwrap(quantity): java.lang.Integer)
      .optionallyWith(
        items.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.items)
      .build()
  }
  def asReadOnly: zio.aws.cloudfront.model.InvalidationList.ReadOnly =
    zio.aws.cloudfront.model.InvalidationList.wrap(buildAwsValue())
}
object InvalidationList {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudfront.model.InvalidationList =
      zio.aws.cloudfront.model.InvalidationList(
        marker,
        nextMarker.map(value => value),
        maxItems,
        isTruncated,
        quantity,
        items.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: String
    def nextMarker: Option[String]
    def maxItems: Integer
    def isTruncated: Boolean
    def quantity: Integer
    def items
        : Option[List[zio.aws.cloudfront.model.InvalidationSummary.ReadOnly]]
    def getMarker: ZIO[Any, Nothing, String] = ZIO.succeed(marker)
    def getNextMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getMaxItems: ZIO[Any, Nothing, Integer] = ZIO.succeed(maxItems)
    def getIsTruncated: ZIO[Any, Nothing, Boolean] = ZIO.succeed(isTruncated)
    def getQuantity: ZIO[Any, Nothing, Integer] = ZIO.succeed(quantity)
    def getItems: ZIO[Any, AwsError, List[
      zio.aws.cloudfront.model.InvalidationSummary.ReadOnly
    ]] = AwsError.unwrapOptionField("items", items)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ) extends zio.aws.cloudfront.model.InvalidationList.ReadOnly {
    override val marker: String = impl.marker(): String
    override val nextMarker: Option[String] =
      scala.Option(impl.nextMarker()).map(value => value: String)
    override val maxItems: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.maxItems())
    override val isTruncated: Boolean = impl.isTruncated(): Boolean
    override val quantity: Integer =
      zio.aws.cloudfront.model.primitives.Integer(impl.quantity())
    override val items
        : Option[List[zio.aws.cloudfront.model.InvalidationSummary.ReadOnly]] =
      scala
        .Option(impl.items())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.cloudfront.model.InvalidationSummary.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.InvalidationList
  ): zio.aws.cloudfront.model.InvalidationList.ReadOnly = new Wrapper(impl)
}
